     /**
     * \brief JSON Array : Unit Test
   *
   * \author Mihael Schmidt
   * \date   01.07.2011
      * 
      * \todo test case for jsona_toString()
   */

     H nomain

      *-------------------------------------------------------------------------
      * Prototypes
      *-------------------------------------------------------------------------
     D test_basics...
     D                 PR
     D test_empty...
     D                 PR
     D test_addTypedValues...
     D                 PR
     D test_addTypedValuesPositioned...
     D                 PR

      /copy RPGUNIT1,TESTCASE
      /copy 'json/json_h.rpgle'
      /copy 'message_h.rpgle'


      *-------------------------------------------------------------------------
      * Procedures
      *-------------------------------------------------------------------------
     P test_basics...
     P                 B                   export
      *
     D json            S               *
     D jsona           S               *
   /free
       json = json_create();
       jsona = jsona_create();
       json_putArray(json : 'array' : jsona);
       assert(json <> *null : 'Newly created json object mustn''t be null.');
       assert(jsona <> *null : 'Newly created json array mustn''t be null.');
       
       jsona_putBoolean(jsona : *on);
       iEqual(jsona_size(jsona) : 1);
       assert(jsona_getBoolean(jsona : 0) = *on :
              'Wrong value for added boolean value.');
       
       jsona_remove(jsona : 0);
       iEqual(jsona_size(jsona) : 0);
       
       jsona_putInt(jsona : 358);
       iEqual(jsona_getInt(jsona : 0) : 358);
       iEqual(jsona_size(jsona) : 1);
       
       jsona_putNull(jsona);
       iEqual(jsona_size(jsona) : 2);
       
       jsona_putString(jsona : 'Mihael');
       iEqual(jsona_size(jsona) : 3);
       aEqual(%str(jsona_getString(jsona : 2)) : 'Mihael');
       
       json_dispose(json);
       
       assert(json = *null : 'Dispose json object pointer must be *null.');
   /end-free
     P                 E

     
     P test_size       B                   export
     D                 PI
      *
     D array           S               *
      *
      /free
       array = jsona_create();
       
       iEqual(jsona_size(array) : 0);
       
       jsona_putNull(array);
       iEqual(jsona_size(array) : 1);
       
       jsona_putString(array : 'Mihael');
       iEqual(jsona_size(array) : 2);
       
       jsona_clear(array);
       iEqual(jsona_size(array) : 0);
       
       jsona_dispose(array);
      /end-free 
     P                 E
     
     P test_addTypedValues...
     P                 B                   export
      *
     D array           S               *
     D object          S               *
     D array2          S               *
      /free
       array = jsona_create();
       array2 = jsona_create();
       object = json_create();
       json_putString(object : 'Mihael' : 'Schmidt');
       
       jsona_putArray(array : array2);
       jsona_putObject(array : object);
       jsona_putBoolean(array : *on);
       jsona_putDouble(array : 1.2345);
       jsona_putInt(array : 358);
       jsona_putLong(array : 123456789012345);
       jsona_putNull(array);
       jsona_putString(array : 'Mihael');
       jsona_putString(array : 'Mihael' : *omit : 4);
       jsona_putString(array : 'Mihael' : 8 : 2);
       iEqual(jsona_size(array) : 10);
       
       array2 = jsona_getArray(array : 0);
       assert(array2 <> *null : 'JSON array retrieved from array must exist.');
       iEqual(jsona_size(array2) : 0);
       
       object = jsona_getObject(array : 1);
       assert(object <> *null : 'JSON object retrieved from array must exist.');
       aEqual('Schmidt' : %str(json_getString(object : 'Mihael')));
       
       assert(jsona_getBoolean(array : 2) : 'Retrieved boolean value doesn''t '+
                                            'match.');
       assert(jsona_getDouble(array : 3) = 1.2345 : 'Retrieved double value ' +
                                                    'doesn''t match.');
       assert(jsona_getInt(array : 4) = 358 : 'Retrieved int value doesn''t ' + 
                                              'match.');
       assert(jsona_getLong(array : 5) = 123456789012345 : 'Retrieved ' +
              'long value doesn''t match.');
       assert(jsona_getEntryType(array : 6) = JSON_TYPE_NULL : 'JSON array ' +
              'entry for previous inserted Null was not of type Null.');
       assert(jsona_isNull(array : 6) : 'JSON array ' +
              'entry for previous inserted Null was not Null.');
       aEqual('Mihael' : %str(jsona_getString(array : 7)));
       aEqual('Mi' : %str(jsona_getString(array : 8)));
       aEqual('Miha' : %str(jsona_getString(array : 9)));
                                     
       jsona_dispose(array);
      /end-free
     P                 E
 
 
     P test_addTypedValuesPositioned...
     P                 B                   export
      *
     D array           S               *
     D object          S               *
     D array2          S               *
      /free
       array = jsona_create();
       array2 = jsona_create();
       object = json_create();
       json_putString(object : 'Mihael' : 'Schmidt');
       
       jsona_putArray(array : array2);
       jsona_putObject(array : object);
       jsona_putBoolean(array : *on : 1);
       jsona_putDouble(array : 1.2345 : 1);
       jsona_putInt(array : 358 : 2);
       jsona_putLong(array : 123456789012345 : 4);
       jsona_putNull(array : 0);
       jsona_putString(array : 'Mihael' : 1);
       
       iEqual(jsona_size(array) : 8);
       
       array2 = jsona_getArray(array : 2);
       assert(array2 <> *null : 'JSON array retrieved from array must exist.');
       iEqual(jsona_size(array2) : 0);
       
       object = jsona_getObject(array : 7);
       assert(object <> *null : 'JSON object retrieved from array must exist.');
       aEqual('Schmidt' : %str(json_getString(object : 'Mihael')));
       
       assert(jsona_getBoolean(array : 5) : 'Retrieved boolean value doesn''t '+
                                            'match.');
       assert(jsona_getDouble(array : 3) = 1.2345 : 'Retrieved double value ' +
                                                    'doesn''t match.');
       assert(jsona_getInt(array : 4) = 358 : 'Retrieved int value doesn''t ' + 
                                              'match.');
       assert(jsona_getLong(array : 6) = 123456789012345 : 'Retrieved ' +
              'long value doesn''t match.');
       assert(jsona_getEntryType(array : 0) = JSON_TYPE_NULL : 'JSON array ' +
              'entry for previous inserted Null was not of type Null.');
       aEqual('Mihael' : %str(jsona_getString(array : 1)));
                                     
       jsona_dispose(array);
      /end-free
     P                 E
     